@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: hostedit.php,v 1.6 2004/04/23 15:51:11 gruberroland Exp $
+$Id: hostedit.php,v 1.7 2004/12/17 16:47:23 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Tilo Lutz
@@ -260,6 +260,9 @@ do { // X-Or, only one if() can be true
 		$_SESSION['account_'.$varkey.'_account_new'] = loadHostProfile('default');
 		$account_new =& $_SESSION['account_'.$varkey.'_account_new'];
 		$account_new ->type = 'host';
+		$account_new->smb_flags['W'] = 1;
+		$account_new->general_homedir = '/dev/null';
+		$account_new->general_shell = '/bin/false';
 		break;
 		}
 	// Load Profile and reset all attributes to settings in profile
