@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main.php,v 1.1.1.1 2003/12/29 22:11:16 gruberroland Exp $
+$Id: main.php,v 1.2 2004/07/04 11:06:46 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003  Roland Gruber
@@ -51,7 +51,17 @@ if ($_SESSION['config']->is_samba3()) {
 	$doms = $_SESSION['ldap']->search_domains($_SESSION['config']->get_domainSuffix());
 }
 
-echo $_SESSION['header'];
+// get encoding
+$lang = explode(":",$_SESSION['language']);
+$lang = $lang[1];
+
+echo "<?xml version=\"1.0\" encoding=\"$lang\"?>\n";
+echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\" \"http://www.w3.org/TR/html4/frameset.dtd\">\n";
+echo "<html>\n";
+echo "<head>\n";
+echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=$lang\">\n";
+echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n";
+echo "<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
 echo ("<title>LDAP Account Manager</title>\n");
 echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">");
 echo ("</head>\n");
